@@ -14,7 +14,7 @@ from einspect.compat import Version
 if TYPE_CHECKING:
     from einspect.structs import PyObject
 
-__all__ = ("ptr", "Array", "NULL", "_SelfPtr")
+__all__ = ("ptr", "Pointer", "Array", "NULL", "_SelfPtr", "SupportsLessThan")
 
 _T = TypeVar("_T")
 
@@ -107,6 +107,11 @@ class char_p(ctypes.c_char_p):
     pass
 
 
+class SupportsLessThan(typing.Protocol):  # pragma: no cover
+    def __lt__(self, other: Self) -> bool:
+        ...
+
+
 if not TYPE_CHECKING:
     # Runtime overrides
     globals().update(
